@@ -203,13 +203,16 @@ class DateFieldTrigger(Trigger):
         help_text=_("Check this in order to trigger every year"),
     )
 
-    def triggerdates(self, object) -> typing.Generator[datetime.datetime, None, None]:
+    def triggerdates(
+        self, object
+    ) -> typing.Generator[typing.Optional[datetime.datetime], None, None]:
         for field in (f.strip() for f in self.field.split(",")):
             field_value = getattr(object, field)
             # not sure if doing calls here is a good idea, will see...
             field_value = field_value() if callable(field_value) else field_value
             if field_value is None:
-                return None
+                yield None
+                continue
             if isinstance(field_value, datetime.date) and not isinstance(
                 field_value, datetime.datetime
             ):
